The things found in this directory have been deprecated and will be removed in
the 3008.0 release of salt. The Salt maintainers are not aware of anyone
relying on these files. Please file a bug report if you are relying any files
that have been moved to this 'old' directory.
